Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(282)

Unified Diff: content/browser/ssl/ssl_manager.cc

Issue 2222003002: Combine SSLCertErrorHandler and SSLErrorHandler (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: rebase Created 4 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « content/browser/ssl/ssl_error_handler.cc ('k') | content/browser/ssl/ssl_policy.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: content/browser/ssl/ssl_manager.cc
diff --git a/content/browser/ssl/ssl_manager.cc b/content/browser/ssl/ssl_manager.cc
index 4526ab3d13e622ed6a6437f776e42ec9eb153273..bcec11679a6e451713bf1442581e70bdbb97f3bc 100644
--- a/content/browser/ssl/ssl_manager.cc
+++ b/content/browser/ssl/ssl_manager.cc
@@ -13,7 +13,7 @@
#include "content/browser/frame_host/navigation_entry_impl.h"
#include "content/browser/loader/resource_dispatcher_host_impl.h"
#include "content/browser/loader/resource_request_info_impl.h"
-#include "content/browser/ssl/ssl_cert_error_handler.h"
+#include "content/browser/ssl/ssl_error_handler.h"
#include "content/browser/ssl/ssl_policy.h"
#include "content/browser/web_contents/web_contents_impl.h"
#include "content/common/ssl_status_serialization.h"
@@ -61,14 +61,14 @@ void SSLManager::OnSSLCertificateError(
<< " url: " << url.spec()
<< " cert_status: " << std::hex << ssl_info.cert_status;
// A certificate error occurred. Construct a SSLCertErrorHandler object and
// hand it over to the UI thread for processing.
BrowserThread::PostTask(
BrowserThread::UI, FROM_HERE,
- base::Bind(&SSLCertErrorHandler::Dispatch,
- new SSLCertErrorHandler(delegate, resource_type, url, ssl_info,
- fatal),
- web_contents_getter));
+ base::Bind(
+ &SSLErrorHandler::Dispatch,
+ new SSLErrorHandler(delegate, resource_type, url, ssl_info, fatal),
+ web_contents_getter));
}
// static
« no previous file with comments | « content/browser/ssl/ssl_error_handler.cc ('k') | content/browser/ssl/ssl_policy.h » ('j') | no next file with comments »
@@ -61,14 +61,14 @@ void SSLManager::OnSSLCertificateError(
<< " url: " << url.spec()
<< " cert_status: " << std::hex << ssl_info.cert_status;
- // A certificate error occurred. Construct a SSLCertErrorHandler object and
+ // A certificate error occurred. Construct a SSLErrorHandler object and
// hand it over to the UI thread for processing.
BrowserThread::PostTask(

Powered by Google App Engine
This is Rietveld 408576698